@@ -1,7 +1,9 @@
 from datetime import datetime
 from typing import Any, Dict, Sequence, Type, TypeAlias, TypeVar, Union, cast
 
+import pytz
 from pymongo.errors import DuplicateKeyError
+
 from redb.interface.errors import (
     CannotUpdateIdentifyingField,
     UniqueConstraintViolation,
@@ -38,12 +40,12 @@ T = TypeVar("T", bound="Document")
 
 class Document(BaseDocument):
     id: str = Field(alias="_id")  # type: ignore
-    created_at: datetime = Field(default_factory=datetime.utcnow)  # type: ignore
-    updated_at: datetime = Field(default_factory=datetime.utcnow)  # type: ignore
+    created_at: datetime = Field(default_factory=lambda: datetime.now(pytz.UTC))  # type: ignore
+    updated_at: datetime = Field(default_factory=lambda: datetime.now(pytz.UTC))  # type: ignore
 
     class Config:
         json_encoders = {
-            datetime: lambda d: d.isoformat(),  # TODO: shouldn't we keep this as datetime?
+            datetime: lambda d: d.isoformat(),
             DBRef: lambda ref: dict(ref.as_doc()),
             ObjectId: str,
         }
@@ -170,10 +172,13 @@ class Document(BaseDocument):
     def insert(self: T) -> InsertOneResult:
         collection = Document._get_collection(self.__class__)
         data = _format_document_data(self)
-        return collection.insert_one(
-            cls=self.__class__,
-            data=data,
-        )
+        try:
+            return collection.insert_one(
+                cls=self.__class__,
+                data=data,
+            )
+        except DuplicateKeyError as e:
+            raise UniqueConstraintViolation(dup_keys=e.details["keyValue"])
 
     @classmethod
     def insert_one(
@@ -202,10 +207,13 @@ class Document(BaseDocument):
         values_size = len(data[keys[0]])
         instances = [None] * values_size
         instances = [{key: data[key][i] for key in keys} for i in range(values_size)]
-        return collection.insert_many(
-            cls=cls,
-            data=instances,
-        )
+        try:
+            return collection.insert_many(
+                cls=cls,
+                data=instances,
+            )
+        except DuplicateKeyError as e:
+            raise UniqueConstraintViolation(dup_keys=e.details["keyValue"])
 
     @classmethod
     def insert_many(
@@ -295,7 +303,7 @@ class Document(BaseDocument):
         collection.update_one(
             cls=self.__class__,
             filter=filter,
-            update={"$set": {"updated_at": str(datetime.utcnow())}},
+            update={"$set": {"updated_at": datetime.now(pytz.UTC).isoformat()}},
         )
         return result
 
@@ -332,7 +340,7 @@ class Document(BaseDocument):
             collection.update_one(
                 cls=cls,
                 filter=filter,
-                update={"$set": {"updated_at": str(datetime.utcnow())}},
+                update={"$set": {"updated_at": datetime.now(pytz.UTC).isoformat()}},
             )
         except DuplicateKeyError as e:
             raise UniqueConstraintViolation(dup_keys=e.details["keyValue"])
@@ -371,7 +379,7 @@ class Document(BaseDocument):
             collection.update_many(
                 cls=cls,
                 filter=filter,
-                update={"$set": {"updated_at": str(datetime.utcnow())}},
+                update={"$set": {"updated_at": datetime.now(pytz.UTC).isoformat()}},
             )
         except DuplicateKeyError as e:
             raise UniqueConstraintViolation(dup_keys=e.details["keyValue"])
